%define boost_version 1.34
%define qt_version 4.2

Name:           CGAL
Version:        3.6.1
Release:        2%{?dist}
Summary:        Computational Geometry Algorithms Library

Group:          System Environment/Libraries
License:        QPL and LGPLv2 and LGPLv2+
URL:            http://www.cgal.org/
Source0:        https://gforge.inria.fr/frs/download.php/27224/CGAL-3.6.1.tar.xz
Source10:       CGAL-README.Fedora

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# Required devel packages.
BuildRequires: cmake
BuildRequires: gmp-devel
BuildRequires: boost-devel >= %{boost_version}
BuildRequires: qt3-devel
BuildRequires: qt-devel >= %{qt_version}
BuildRequires: zlib-devel
BuildRequires: blas-devel lapack-devel
BuildRequires: mpfr-devel

%description
Libraries for CGAL applications.
CGAL is a collaborative effort of several sites in Europe and
Israel. The goal is to make the most important of the solutions and
methods developed in computational geometry available to users in
industry and academia in a C++ library. The goal is to provide easy
access to useful, reliable geometric algorithms.


%package devel
Group:          Development/Libraries
Summary:        Development files and tools for CGAL applications
Requires:       cmake
Requires:       %{name} = %{version}-%{release}
Requires:       boost-devel >= %{boost_version}
Requires:       qt-devel >= %{qt_version}
Requires:       blas-devel lapack-devel qt3-devel zlib-devel gmp-devel
Requires:        mpfr-devel
%description devel
The %{name}-devel package provides the headers files and tools you may need to 
develop applications using CGAL.


%package demos-source
Group:          Documentation
Summary:        Examples and demos of CGAL algorithms
Requires:       %{name}-devel = %{version}-%{release}
%description demos-source
The %{name}-demos-source package provides the sources of examples and demos of
CGAL algorithms.


%prep
%setup -q

# Fix some file permissions
chmod a-x examples/Boolean_set_operations_2/amer_*.bps
chmod a-x examples/Boolean_set_operations_2/bezier_traits_adapter2.cpp
chmod a-x demo/Segment_Delaunay_graph_2/include/CGAL/Constraints_loader.h

# Install README.Fedora here, to include it in %%doc
install -p -m 644 %{SOURCE10} ./README.Fedora

%build

if [ "%{version}" = "3.6.1" ]; then
  CHANGE_SOVERSION="-DCGAL_SOVERSION:STRING=5.0.1"
fi

mkdir build
pushd build
%cmake -DCGAL_INSTALL_LIB_DIR=%{_lib} ${CHANGE_SOVERSION} ..
make VERBOSE=1 %{?_smp_mflags}
popd


%install
rm -rf %{buildroot}

pushd build

make install DESTDIR=$RPM_BUILD_ROOT

popd

# Install demos and examples
mkdir -p %{buildroot}%{_datadir}/CGAL
touch -r demo %{buildroot}%{_datadir}/CGAL/
cp -a demo %{buildroot}%{_datadir}/CGAL/demo
cp -a examples %{buildroot}%{_datadir}/CGAL/examples

%clean
rm -rf %{buildroot}


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files
%defattr(-,root,root,-)
%doc AUTHORS LICENSE LICENSE.FREE_USE LICENSE.LGPL LICENSE.QPL CHANGES README.Fedora
%{_libdir}/libCGAL*.so.5
%{_libdir}/libCGAL*.so.5.0.1


%files devel
%defattr(-,root,root,-)
%{_includedir}/CGAL
%{_libdir}/libCGAL*.so
%{_libdir}/CGAL
%dir %{_datadir}/CGAL
%{_bindir}/*
%exclude %{_bindir}/cgal_make_macosx_app
%{_mandir}/man1/cgal_create_cmake_script.1.gz


%files demos-source
%defattr(-,root,root,-)
%dir %{_datadir}/CGAL
%{_datadir}/CGAL/demo
%{_datadir}/CGAL/examples
%exclude %{_datadir}/CGAL/*/*/skip_vcproj_auto_generation

%changelog
* Tue Aug  3 2010 Laurent Rineau <Laurent.Rineau__fedora@normalesup.org> - 3.6.1-2
- Rebuild (because of Boost SONAME bump)

* Thu Jul  1 2010 Laurent Rineau <Laurent.Rineau__fedora@normalesup.org> - 3.6.1-1
- New upstream release
- Fix some file permissions (rpmlint warnings)
- Upstream version CGAL-3.6.1 has not modified the build number of the
  SOVERSION. Fix that with a CMake option -DCGAL_SOVERSION=...
- Fix changelog: use of macro is a single percent, instead of two, and add
  my real name so several changelog entries.

* Sat Mar  6 2010 Laurent Rineau <Laurent.Rineau__fedora@normalesup.org> - 3.6-0.1.beta1
- New upstream release

* Mon Jan 18 2010 Laurent Rineau <Laurent.Rineau__fedora@normalesup.org> - 3.5.1-2
- Rebuild after Boost upgrade (and soname bump)

* Thu Dec 24 2009 Laurent Rineau <Laurent.Rineau__fedora@normalesup.org> - 3.5.1-1
- New upstream release

* Tue Nov 24 2009 Kevin Kofler <Kevin@tigcc.ticalc.org> - 3.5-3
- Rebuild for Qt 4.6.0 RC1 in F13 (was built against Beta 1 with unstable ABI)

* Mon Nov  2 2009 Laurent Rineau <Laurent.Rineau__fedora@normalesup.org> - 3.5-2
- Use system's FindBoost macro instead of a copy from CGAL (bug #532431).

* Sun Oct 18 2009 Laurent Rineau <Laurent.Rineau__fedora@normalesup.org> - 3.5-1
- New upstream release: finale version of CGAL-3.5.

* Thu Jul 30 2009 Laurent Rineau <Laurent.Rineau__fedora@normalesup.org> - 3.5-0.2.beta1
- No longer requires /etc/profile.d/

* Thu Jul 30 2009 Laurent Rineau <Laurent.Rineau__fedora@normalesup.org> - 3.5-0.1.beta1
- Update to CGAL-3.5-beta1.
- New compilation process: CMake.
- No longer any need for patches.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3.1-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Laurent Rineau <Laurent.Rineau__fedora@normalesup.org> - 3.3.1-13
- noarch CGAL-demos-source, which is purely data.

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3.1-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Apr  1 2008 Rex Dieter <rdieter@fedoraproject.org> - 3.3.1-11
- -devel: Requires: qt3-devel

* Tue Apr  1 2008 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 3.3.1-10
- Rebuild for Rawhide. BR: qt3-devel instead of qt-devel (which is now Qt-4.x).

* Mon Feb 11 2008 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 3.3.1-9
- Rebuild with g++-4.3.

* Mon Nov  5 2007 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 3.3.1-8
- Add Requires: mpfr-devel for CGAL-devel.

* Mon Oct 22 2007 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 3.3.1-6
- fix /etc/profile.d/cgal.*

* Sun Oct 21 2007 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 3.3.1-3
- gawk and coreutils are not required in BR (see exceptions list)
- fix multilib issues (bug #340821):
  - rename %%{_datadir}/CGAL/cgal.mk to %%{_datadir}/CGAL/cgal-%%{_arch}.mk
  - remove the arch-specific comment from %%{_includedir}/CGAL/compiler_config.h

* Mon Sep  3 2007 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 3.3.1-2
- Fix soversion.

* Mon Sep  3 2007 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 3.3.1-1
- New upstream bug-fixes release.

* Fri Aug 24 2007 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 3.3-7
- Add BR: mpfr since F-8.

* Fri Aug 24 2007 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 3.3-6
- Add BR: gawk

* Thu Aug 23 2007 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 3.3-5
- License: tag fixed.

* Thu Jun  7 2007 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.3-4
- Move the makefile back to %%{_datadir}/CGAL, and rename it cgal.mk (sync
  with Debian package). That file is not a config file, but just an example
  .mk file that can be copied and adapted by users.
- Fix the %%{_sysconfdir}/profile.d/cgal.* files (the csh one was buggy).
- CGAL-devel now requires all its dependancies.

* Sat Jun  2 2007 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.3-2
- Official CGAL-3.3 release
- Skip file named "skip_vcproj_auto_generation"

* Wed May 30 2007 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.3-0.1.RC1
- New upstream version: 3.3-RC1
- Obsolete patches CGAL-3.2.1-build-libCGALQt-shared.patch,
                   CGAL-3.2.1-build-no-static-lib.patch,
                   CGAL-3.2.1-config.h-endianness_detection.patch.
  These patchs have been merged and adapted by upstream.
- New option --disable-static
- Shipped OpenNL and CORE have been renamed by upstream:
    - %%{_includedir}/OpenNL is now %%{_includedir}/CGAL/OpenNL
    - %%{_includedir}/CORE is now %%{_includedir}/CGAL/CORE
    - libCORE has been rename libCGALcore++
  Reasons:
    - CGAL/OpenNL is a special version of OpenNL, rewritten for CGAL 
      in C++ by the OpenNL author,
    - CGAL/CORE is a fork of CORE-1.7. CORE-1.7 is no longer maintained by 
      its authors, and CORE-2.0 is awaited since 2004.
  In previous releases of this package, CORE was excluded from the package, 
  because %%{_includedir}/CORE/ was a name too generic (see comment #8 of
  #bug #199168). Since the headers of CORE have been moved to
  %%{_includedir}/CGAL/CORE, CORE is now shipped with CGAL.
- move %%{_datadir}/CGAL/make/makefile to %%{_sysconfdir}/CGAL/makefile
(because it is a config file).

* Thu Nov  2 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2.1-19
- Fix CGAL-3.2.1-build-libCGALQt-shared.patch (bug #213675)

* Fri Sep 15 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2.1-18
- Move LICENSE.OPENNL to %%doc CGAL-devel (bug #206575).

* Mon Sep 11 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2.1-17
- libCGALQt.so needs -lGL
- remove %%{_bindir}/cgal_make_macosx_app

* Sat Sep  11 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2.1-16
- Remove CORE support. Its acceptance in Fedora is controversial (bug #199168).
- Exclude .vcproj files from the -demos-source subpackage.
- Added a patch to build *shared* library libCGALQt.
- Added a patch to avoid building static libraries.
- Fixed the License: tag.

* Thu Aug 17 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2.1-15
- Change the permissions of %%{_sysconfdir}/profile.d/cgal.*sh
- Remove the meta package CGAL. CGAL-libs is renamed CGAL.
- Added two patchs:
  - CGAL-3.2.1-config.h-endianness_detection.patch which is an upstream patch
    to fix the endianness detection, so that is is no longer hard-coded in
    <CGAL/compiler_config.h>,
  - CGAL-3.2.1-install_cgal-no_versions_in_compiler_config.h.patch that
    removes hard-coded versions in <CGAL/compiler_config.h>.

* Wed Aug 16 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2.1-14
- Simplified spec file, for Fedora Extras.

* Mon Jul 17 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2.1-13
- Change CGAL-README.Fedora, now that Installation.pdf is no longer in the
tarball.

* Mon Jul 17 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2.1-12
- Remove unneeded  -R/-L/-I flags from %%{_datadir}/CGAL/make/makefile

* Mon Jul 17 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2.1-11
- Fix the soversion.
- Fix %%{cgal_prefix} stuff!!
- Quote 'EOF', so that the lines are not expanded by the shell.

* Tue Jul  4 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2.1-10
- Fix makefile.sed so that %%{buildroot} does not appear in 
  %%{_datadir}/CGAL/make/makefile.

* Sun Jul  2 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2.1-9
- Remove Obsoletes: in the meta-package CGAL.

* Sun Jul  2 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2.1-8
- Fix the localisation of demo and examples.

* Sun Jul  2 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2.1-6
- Set Requires, in sub-packages.

* Sun Jul  2 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2.1-5
- CGAL-3.2.1
- Sub-package "demo" is now named "demos-source" (Fedora guidelines).
- Fix some rpmlint warnings
- Added README.Fedora, to explain why the documentation is not shipped, and how CGAL is divided in sub-packages.


* Sat Jul  1 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2-4
- Use %%{_datadir}/CGAL instead of %%{_datadir}/%%{name}-%%{version}
- Fix %%{_datadir}/CGAL/makefile, with a sed script.
- Added a new option %%set_prefix (see top of spec file).

* Sat Jul  1 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2-3
- Use less "*" in %%files, to avoid futur surprises.
- Remove %%{_sysconfdir}/profile.d/cgal.* from %%files if %%cgal_prefix is not empty.
- Fix %%build_doc=0 when %%fedora is set. New option macro: %%force_build_doc.

* Fri Jun 30 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2-2
- Fix some end-of-lines in %%prep, to please rpmlint.

* Mon May 22 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 3.2-1
- Remove README from %%doc file: it describes the tarball layout.
- Updated to CGAL-3.2.
- Added examples in the -demo subpackage.
- Cleaning up, to follow Fedora Guidelines.
- The -doc subpackage cannot be build on Fedora (no license).
- Add ldconfig back.
- No prefix.

* Fri Apr 28 2006 Laurent Rineau <laurent.rineau__fc_extra@normalesup.org> - 3.2-0.447
- Update to CGAL-3.2-447.

* Fri Apr 21 2006 Laurent Rineau <laurent.rineau__fc_extra@normalesup.org> - 3.2-0.440
- Updated to CGAL-3.2-I-440.

* Wed Apr 19 2006 Laurent Rineau <laurent.rineau__fc_extra@normalesup.org> - 3.2-0.438
- Added a patch to install_cgal, to require support for BOOST, BOOST_PROGRAM_OPTIONS, X11, GMP, MPFR, GMPXX, CORE, ZLIB, and QT.
- Move scripts to %%{_bindir}
- %%{_libdir}/CGAL-I now belong to CGAL and CGAL-devel, so that it disappears when the packages are removed.

* Wed Apr 12 2006 Laurent Rineau <laurent.rineau__fc_extra@normalesup.org> - 3.2-0.431
- Updated to CGAL-3.2-I-431.
- Remove the use of ldconfig.
- Changed my email address.
- No longer need for patch0.
- Pass of rpmlint.
- Remove unneeded Requires: tags (rpm find them itself).
- Change the release tag.
- Added comments at the beginning of the file.
- Added custom ld flags, on 64bits archs (so that X11 is detected).

* Tue Apr 11 2006 Laurent Rineau <laurent.rineau__fc_extra@normalesup.org>
- Removed -g and -O2 from CUSTOM_CXXFLAGS, in the makefile only.
  They are kept during the compilation of libraries.
- Added zlib in dependencies.
- Added a patch to test_ZLIB.C, until it is merged upstream.

* Fri Mar 31 2006 Naceur MESKINI <nmeskini@sophia.inria.fr>
- adding a test in the setup section.

* Mon Mar 13 2006 Naceur MESKINI <nmeskini@sophia.inria.fr>
- delete the patch that fixes the perl path.
- add build_doc and build_demo flags.

* Fri Mar 10 2006 Naceur MESKINI <nmeskini@sophia.inria.fr>
- Adding new sub-packages doc(pdf&html) and demo.
- Add internal_release flag. 

* Thu Mar 09 2006 Naceur MESKINI <nmeskini@sophia.inria.fr>
- Cleanup a specfile.

